@@ -10,7 +10,7 @@ style_widget <- function(hw=NULL, style="", addl_selector="") {
     # borrow htmlwidgets unique id creator
     elementId <- sprintf(
       'htmlwidget-%s',
-      createWidgetId()
+      get('createWidgetId',envir = asNamespace('htmlwidgets'))()
     )
     hw$elementId <- elementId
   }
@@ -27,19 +27,3 @@ style_widget <- function(hw=NULL, style="", addl_selector="") {
   )
 }
 
-createWidgetId <- 
-function (bytes = 10) 
-{
-  sysSeed <- .GlobalEnv$.Random.seed
-  if (!is.null(.globals$idSeed)) {
-    .GlobalEnv$.Random.seed <- .globals$idSeed
-  }
-  on.exit({
-    .globals$idSeed <- .GlobalEnv$.Random.seed
-    .GlobalEnv$.Random.seed <- sysSeed
-  })
-  paste(format(as.hexmode(sample(256, bytes, replace = TRUE) - 
-                            1), width = 2), collapse = "")
-}
-
-environment(createWidgetId)=asNamespace('htmlwidgets')
\ No newline at end of file
